package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"4```````!``````````#"Q````
M`````````$``.``+`$``&P`:``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````*@9````````J!D`````````
M$`````````$````%`````"``````````(``````````@````````U3T`````
M``#5/0`````````0`````````0````0`````8`````````!@`````````&``
M```````X1@```````#A&`````````!`````````!````!@```-"K````````
MT+L```````#0NP```````%`$````````T!0`````````$`````````(````&
M````X*L```````#@NP```````."[````````$`(````````0`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````)">````````D)X```````"0G@``
M`````/P`````````_``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``#0JP```````-"[````````T+L````````P!````````#`$`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`/3;&)Y`])(!(:M&Z^M1'A3.BS:N!````!`````!````1TY5```````#
M`````@`````````1````/P````0````(````(!P0``5`!(8H`D`$D(8`A(()
M`"!)(`0(N*(11;H``@H`````/P```$(```!%````1@```$T```!.````4```
M`%0```!5````5P```%@```!;````70```%\``````````````&[%WQ_.WD<M
M:W^:?"[%F[8@_^0.U634?-EQ6!SB1\8!0OK7AZQ+X\"ZXY)\PN4_+/JA;&"S
M`8MO:PE#UF:OS&;%N9Q`0D75[,2)!9"(!W#3.?*+'`T4XI[:S>.>,V+;[16,
M)<P,.I<+5J2;EJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````
M````````````````````````````X0```!(`````````````````````````
MB@$``!(`````````````````````````Y`$``!(`````````````````````
M````P@$``!(``````````````````````````0```"``````````````````
M````````ZP$``!(`````````````````````````=P(``!(`````````````
M``````````````(``!(`````````````````````````10$``!(`````````
M````````````````7P(``!(`````````````````````````5P(``!(`````
M````````````````````=````!(`````````````````````````3P,``!(`
M````````````````````````W````!(`````````````````````````(P(`
M`!(`````````````````````````%0(``!(`````````````````````````
MTP$``!(`````````````````````````<`(``!(`````````````````````
M````@`(``!(`````````````````````````-P$``!(`````````````````
M````````!0$``!(`````````````````````````<P$``!(`````````````
M````````````MP$``!(`````````````````````````R@$``!(`````````
M````````````````X`(``!(`````````````````````````8`$``!(`````
M````````````````````^0$``!(`````````````````````````A0$``!(`
M````````````````````````Q`(``!(`````````````````````````O0(`
M`!(`````````````````````````$P$``!(`````````````````````````
M'0```"``````````````````````````-P(``!(`````````````````````
M````5````!(`````````````````````````HP$``!(`````````````````
M````````;`$``!(`````````````````````````@P```!(`````````````
M````````````CP```!(`````````````````````````+`$``!(`````````
M````````````````\@```!(`````````````````````````1@```!(`````
M````````````````````Y@```!(`````````````````````````/@(``!(`
M````````````````````````50$``!(`````````````````````````P```
M`!(`````````````````````````\0$``!(`````````````````````````
M?@$``!(`````````````````````````K@(``!(`````````````````````
M````AP(``!(`````````````````````````8P```!(`````````````````
M````````M@(``!(`````````````````````````#@(``!(`````````````
M````````````I````!(`````````````````````````(P$``!(`````````
M````````````````3`(``!(`````````````````````````O0$``!(`````
M````````````````````FP$``!(`````````````````````````*0(``!(`
M````````````````````````+````"``````````````````````````!P(`
M`!(`````````````````````````'`(``!(`````````````````````````
MH`(``!(`````````````````````````6`,``!(`#@`@0@````````8!````
M````A`,``!(`#@"`-P```````/P'````````T0(``!(`#@"P(P````````<"
M````````+`,``!(`#@`0+@````````4`````````&`0``!(`#@`@+@``````
M`/(!````````3@0``!(`#@"`/P```````)T"````````!`0``!``&``@P```
M````````````````:P,``!(`#@`@,````````"4`````````D0,``!(`#@#`
M60```````)\!````````J0,``!$`$```8`````````0`````````Z`,``!``
M&`"@T```````````````````$`0``!(`#@`@+0```````#``````````)00`
M`!(`#@!P-@````````L!````````-P0``!(`#@#0-0```````'0`````````
MG`,``!``%P``P```````````````````>`,``!(`#@!0,````````-P`````
M````U@(``!$`&`!`P`````````@`````````9`,``!``%P`@P```````````
M````````UP(``"$`&`!`P`````````@`````````W@,``!$`%P`8P```````
M``@`````````:0(``!$`&`!@P`````````@`````````'`,``!(`#@"P70``
M``````$`````````S@,``!(`#@!070```````%T`````````H@,``!(`#@#`
M)0```````"L`````````100``!(`#@!@60```````%0`````````G@,``"``
M%P``P```````````````````T0```!$`&``@P`````````0`````````V`(`
M`"$`&`!`P`````````@`````````/0,``!(`#@!0-@```````!T`````````
MD0(``"(`````````````````````````N`,``!(`#@!0+0```````+\`````
M````^@,``!(`#@!@6P```````.L!````````LP```!$`&``PP`````````$`
M````````[0,``!(`#@`P,0```````)X$`````````%])5$U?9&5R96=I<W1E
M<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#
M;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R
M;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E
M=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E
M=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I
M<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?
M9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D
M+G-O+C``;&EB8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E
M>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E
M9&%T80!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H
M85]U<&1A=&4`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`
M<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A
M<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H
M85]I;FET`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C$T`$=,24)#7S(N,RXR`$=,24)#7S(N-``````"
M``,``@`"``$``@`"``(``0`"``(``0`"``$``@`"``0``@`"``$``0`!``,`
M`@`%``$``@`#``(``@`!``$`!@`!``,``@`!``$``0`!``$``0`'``$``0`"
M``,``@`"``$``@`"``$``0`"``(``P`'``$``@`"``<``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`"``$``@`!``(``0`!``$``0`!``$``@`!
M``(``0`!``$``0`!``$``@,``!`````@````=1II"0```P!D!`````````$`
M!0`2`P``$`````````!T&6D)```'`'`$```0````E)&6!@``!@!\!```$```
M`'(9:0D```4`AP0``!`````4:6D-```$`),$```0````=1II"0```@!D!```
M`````-"[````````"`````````"@)@```````-B[````````"`````````!@
M)@````````C`````````"``````````(P````````!C`````````"```````
M``#@8@```````,"_````````!@````4``````````````,B_````````!@``
M``D``````````````-"_````````!@```!T``````````````-B_````````
M!@```"```````````````."_````````!@```"@``````````````.B_````
M````!@```#(``````````````/"_````````!@```#L``````````````/B_
M````````!@```%P``````````````"#`````````!0```%D`````````````
M`##`````````!0```%\``````````````$#`````````!0```$\`````````
M`````&#`````````!0```%,```````````````B^````````!P````$`````
M`````````!"^````````!P````(``````````````!B^````````!P````,`
M`````````````""^````````!P````0``````````````"B^````````!P``
M``8``````````````#"^````````!P````<``````````````#B^````````
M!P````@``````````````$"^````````!P````H``````````````$B^````
M````!P````L``````````````%"^````````!P````P``````````````%B^
M````````!P````T``````````````&"^````````!P````X`````````````
M`&B^````````!P````\``````````````'"^````````!P```!``````````
M`````'B^````````!P```!$``````````````("^````````!P```!(`````
M`````````(B^````````!P```!,``````````````)"^````````!P```!0`
M`````````````)B^````````!P```!4``````````````*"^````````!P``
M`!8``````````````*B^````````!P```!<``````````````+"^````````
M!P```!@``````````````+B^````````!P```!D``````````````,"^````
M````!P```!H``````````````,B^````````!P```!L``````````````-"^
M````````!P```!P``````````````-B^````````!P```!X`````````````
M`."^````````!P```!\``````````````.B^````````!P```"$`````````
M`````/"^````````!P```"(``````````````/B^````````!P```",`````
M``````````"_````````!P```"0```````````````B_````````!P```"4`
M`````````````!"_````````!P```"8``````````````!B_````````!P``
M`"<``````````````""_````````!P```"D``````````````"B_````````
M!P```"H``````````````#"_````````!P```"L``````````````#B_````
M````!P```"P``````````````$"_````````!P```"T``````````````$B_
M````````!P```"X``````````````%"_````````!P```"\`````````````
M`%B_````````!P```#```````````````&"_````````!P```#$`````````
M`````&B_````````!P```#,``````````````'"_````````!P```#0`````
M`````````'B_````````!P```#4``````````````("_````````!P```#8`
M`````````````(B_````````!P```#<``````````````)"_````````!P``
M`#@``````````````)B_````````!P```#D``````````````*"_````````
M!P```#H``````````````*B_````````!P```#P``````````````+"_````
M````!P```#T``````````````+B_````````!P```#X`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%S9\``$B%P'0"_]!(@\0(PP```````````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)2*<``!H-@```.F`_/___R52G```9I``````````
M`$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H%_[__TB+-?";``!(BSWQFP``2(GRZ,$Y``"`/2J<````=2_H
M4_W__TB)!82L``!(B<=(A<`/A(@!``#HF_S__XL]]9L``.C@_?__QH#I"0``
M`(L]XYL``.C._?__BSW8FP``@(@Z!````NB\_?__@(@Z!````8M$)!R->`1$
MC6`#2&/_2,'G`^@N_?__2(M\)!!(B<%(B04/K```2(L'2(D!2(T%0#T``$B)
M00A(BP5_FP``2(E!$$B-!2T]``!(B4$8BT0D'(/X`0^.Z0```$B#QPB#P`.Z
M!`````\?@`````!,BP=(8_*#P@%(@\<(3(D$\3G0=>M(F$B+/;*K``!$B>)%
M,<!(QP3!`````$B--;4'``#HD/W__T&)Q(7`=%-(BSV*JP``2(UL)"3H*/S_
M_S'`2(GN2(T]?SL``.B'`0``2(7`=#U(BSUCJP``Z*;[___H(?W__TB+1"0H
M9$@K!"4H````=6-(@\0X1(G@74%<PTB+/3>K``#HNOW__T&)Q.N<2(L]%JL`
M`$B%_W0'Z*0<``#KL$B-/=,Z``!(B>[H(P$``$B)!?2J``!(B<=(A<!TDNO9
MN`0```#I-?___[\!````Z([]___H6?O__V8/'X0``````#'M28G17DB)XDB#
MY/!05$R-!=HW``!(C0US-P``2(T]S/W___\5YID``/0/'T0``$B-/2F:``!(
MC04BF@``2#GX=!5(BP6VF0``2(7`=`G_X`\?@`````###Q^``````$B-/?F9
M``!(C37RF0``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!:69``!(A<!T"/_@
M9@\?1```PP\?@`````#S#Q[Z@#W]F0```'4K54B#/8*9````2(GE=`Q(BSV&
MF0``Z!G]___H9/___\8%U9D```%=PP\?`,,/'X``````\P\>^NEW____#Q^`
M`````$%7059!54%455-(@^P(2(7_#X2Q````3(LM<ID``$V%[0^$H0````^V
M!TF)_TB)]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^
M3(GGZ%+Y__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=
M05Y!7\,/'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````
M3"GK3XUD-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!!5D%505154TB![*``
M``!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````9$@K
M!"4H````#X4I`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#HR_C__TR-
M+1@X``!)B<1(A<!TNTR)Y^CD^O__2(7`#X2K````@'@3+DB-6!-U"8![`0!T
MWP\?`(!X$RX/A*8```!(B>_HUOC__TB)WTF)QNC+^/__08U\!@)(8__HWOG_
M_TF)V4F)Z$R)Z4F)QDB)Q[X!````,<!(Q\+_____Z"S[__^_`0```$B)XDR)
M]N@L^/__3(GW@_C_=!"+1"08)0#P```]`$```'1<Z+_W__],B??HE_?__TR)
MY^@_^O__2(7`#X5;____9@\?1```3(GGZ,CX__](B>_H,/C__^GJ_O__#Q\`
M@'L!+@^%4/___X![`@`/A!C____I0?___P\?@`````#HD_[__^NBZ!SX__]F
M9BX/'X0``````)!52(G^2(G]OP$```!(@>R@````9$B+!"4H````2(F$))@`
M```QP$B)XN@"^O__A<!U-HM4)!B!X@#P``"!^@!```!T"('Z`*```'4>O@(`
M``!(B>_HE_G__X7`#Y3`#[;`ZP</'T0``#'`2(N4))@```!D2"L4)2@```!U
M"4B!Q*````!=P^B%]___#Q]$``!!5KK_#P``055!5$F)]%5(B?U(C3UA-@``
M2('L&!```&1(BP0E*````$B)A"0($```,<!)B>5,B>[HLO;__X7`?DZ-4/],
M8_)"@#PT``^%?0```(72=#E,B?*^+P```$R)[^BY]___2(7`="2+/1Z6``#H
M"?C__TR)\4R)ZDB)[DB)Q^CX^/__ZQ]F#Q]$``"+/?J5``#HY??__TR)XDB)
M[DB)Q^@7]___2(N$)`@0``!D2"L$)2@```!U'$B!Q!@0``!=05Q!74%>PP\?
M1```3&/PZ7_____HH_;__P\?`$%7059!54%454B)]5-(B?M(@^P89$B+!"4H
M````2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ%GV__](C70D!$B)WTF)Q#'`Z/?[
M__](A<`/A`8!``!(B<=)B<7H,_;__TDYQ`^&T@```$QC="0$2<'F`P^V`X3`
M#X2>`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`^CUU[T@IV$B83(LM
M*Y4``$J-?"`"Z`'W__]-`?5)B44`2(7`=%9(BP4.E0``2(U+`4J+%#`/M@.(
M`H3`="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(@\$!B`(\/77KQ@(],<!F
M#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H````#X4'`0``2(/$
M&%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%`$B#P`&$TG7NZ[T/
M'T``3(L]<90``$F#/P`/A+8```!,B?A%,>V02(/`"$2)ZD&#Q0%(@S@`=>^-
M<@-(8_9(P>8#BP5_I```A<!U6\<%<:0```$```!(B??H"?;__TB%P`^$8?__
M_TUC]4R)_DB)QTG!Y@-,B?+HF_;__TB)!024``!(B<%!C44!1(EL)`1(F$C'
M!,$`````Z8C^__]F#Q^$``````!,B?_H2/;__TB)!=&3``!(B<%(A<`/A`;_
M__]-8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5_____H;_3__V9F+@\?
MA```````#Q]``$B#[`B+/6:3``#H4?7__XL]6Y,``.A&]?__2(L5]Y(``$B-
M#8AQ``!(C34Z,P``2(G'Z&GU__^+/3.3``#H'O7__TR-!;(T``!%,<E(C15]
M$@``2(G'3(G!2(TU)3,``$B#Q`CIA_7__P\?@`````!(@^P(BSWVD@``Z.'T
M__](BQ62D@``2(/$"$B-#1]Q``!(B<=(C37.,@``Z0#U__]!5%532('L("``
M`&1(BP0E*````$B)A"08(```,<!(B>5,C:0D$!```.@2\___3(T-D#(``+H!
M$```2(GO08G`2(T-LS(``+X!````,<#H[?7__[H`$```3(GF2(GOZ,WR__]%
M,<"%P'@NC7@!2(G#2&/_Z%CT__])B<!(A<!T&$ACVTR)YDB)QTB)VN@/]/__
MQ@08`$F)P$B+A"08(```9$@K!"4H````=0](@<0@(```3(G`6UU!7,/H`?/_
M_Y#I.____V9F+@\?A```````05=!5DF)]D%505152(G]2(T](C(``%-(@>S(
M$```9$B+!"4H````2(F$)+@0```QP$B-="0<Z%7X__^^+P```$B)[TB)P^C%
M\O__2(7`=$`QP$B)[DB-/>4Q``#H[_O__TB)Z$B+E"2X$```9$@K%"4H````
M#X5R`0``2('$R!```%M=05Q!74%>05_##Q\`2(GO3(TEM#$``.A!\O__3(GF
M3(GW08G'Z#/T__])B<5(A<!TFT&-1P%!@'T``$R--8$R``")1"0,#X3#````
MD$B%VW033(GN2(G?Z-#R__^%P`^$B0```$R)[^CP\?__ZPEF#Q]$``#&`@")
MP8/H`4ACT$P!ZH`Z+W3M`TPD#('Y_P\```^/-?___TR-O"2P````3(GQ38GH
M,<!(@^P(3(T-&C$``+H`$```3(G_5;X!````Z"?T__](C50D,$R)_K\!````
MZ"7Q__]:687`=1"+1"0X)0#P```]`(```'1/3(GF,?_H9?/__TF)Q4B%P`^$
MR?[__T&`?0``#X4^____2(7;=`6`.RYT%$R-+9,P``"Y`0```.E>____#Q\`
M@'L!`'2[Z^0/'X0``````+X!````3(G_Z`/S__^%P'6@3(G^2(T]9C```.AP
M^O__3(G_Z&CS___I=_[__^C^\/__9F8N#Q^$```````/'P`/M@=)B?B$P'07
M9@\?1```2(/'`3PO#[8'3`]$QX3`=>],B<##9F8N#Q^$``````!(A?\/A,<`
M``!5@#\`2(G]#X2B````Z)7P__](C50%_T@YU7(4Z9L```!F#Q]$``!(@^H!
M2#G5="6`.B]T\D@YU0^#?@```$B#Z@%(.=5T#H`Z+W0H2(/J`4@YU77R@'T`
M+W142(T]M2\``%WIK_+__P\?@`````"`.B]U"4B#Z@%(.=5R\D@IZC'`2(U*
M`DB!^0`0``!W&$B#P@&Y`!```$B)[DB-/86/``#H@/'__UW#9@\?1```2(T]
M1R\``%WI6_+__T@YU76SZY(/'T``2(T]+R\``.E$\O__#Q]``$%7059!54%4
M55-(C1TQ+P``2(/L2&8/;P4C;0``9$B+!"4H````2(E$)#@QP#'`2(UL)`P/
M*40D$&8/;P4/;0``9HE$)#`/*40D(`\?1```,<!(B>Y(B=_H(_7__TB%P'0V
M2&-4)`Q(BP6BC@``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```2(T=K"X``)`QP$B)[DB)W^C3]/__2(7`=#9(8U0D#$B+!5*.
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MC1UD+@``D#'`2(GN2(G?Z(/T__](A<!T-DAC5"0,2(L%`HX``$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'1TN``"0,<!(
MB>Y(B=_H,_3__TB%P'0V2&-4)`Q(BP6RC0``2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TEU"T``)`QP$B)[DR)Y^CC\___
M2(7`=#9(8U0D#$B+!6*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!(C1V4+0``D#'`2(GN2(G?Z)/S__](A<!T-DAC5"0,
M2(L%$HT``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$R-+?DL``"0,<!(B>Y,B>_H0_/__TB%P'0V2&-4)`Q(BP7"C```2(T$
MT$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(T]`"T`
M`)`QP$B)[DR)_^CS\O__2(7`=#9(8U0D#$B+!7*,``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C36Z+```D#'`2(GN3(GW
MZ*/R__](A<!T-DAC5"0,2(L%(HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$B-'70L``"0,<!(B>Y(B=_H4_+__TB%P'0V
M2&-4)`Q(BP72BP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```2(T=PBL``)`QP$B)[DB)W^@#\O__2(7`=#9(8U0D#$B+!8*+
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MB>Y(C3W;*P``Z+GQ__](B<9(A<!T"DR)]S'`Z&?U__](B>Y(C3W+*P``,<#H
MEO'__TB)QDB%P'0.2(T]QRL``#'`Z$#U__](B>Y(C3W!*P``,<#H;_'__TB)
MQDB%P'0Z3(GO,<#H'?7__S'`2(TURRL``$R)Y^@,]?__2(M$)#AD2"L$)2@`
M``!U54B#Q$A;74%<05U!7D%?PTB)[DB-/7XK```QP.@<\?__2(G&2(7`=`Q,
MB?\QP.C*]/__ZZM(N%!!4E]#3$5!2#E$)"%UFF:!?"0I3CUUD4B-="0KZ]/H
M0NO__V:02(/L&&1(BP0E*````$B)1"0(BP4HB@``@_C_=!M(BU0D"&1(*Q0E
M*````'5"2(/$&,-F#Q]$``!(C70D!$B-/9LJ```QP.B5\/__2(G",<!(A=)T
M$@^V`CPP#Y7"A,`/E<`/ML`AT(D%TXD``.NNZ,SJ__]F9BX/'X0``````)!(
M@^P(Z,?J__^)Q^APZO__2(7`=`-(BP!(@\0(PP\?`$%5051,C26N*@``54B)
M_4R)YU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z`_P__](A<!T"(`X`$B)
MPW4R2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG,<!;74%<05WIE_/_
M_P\?@`````!(B>Y(B<?HE>S__TB%P'0@2(M$)`AD2"L$)2@```!U=DB#Q!A;
M74%<05W##Q]$``!(B>_HZ.G__TB)WTF)Q>C=Z?__28U\!0+H\^K__TB#[`A)
MB>B^`0```%-(Q\+_____2(G'28G%3(T-("D``$B-#1$J```QP.@T[/__6%I(
MBT0D"&1(*P0E*````'4(3(GNZ4_____HE>G__P\?1```05=!5DR--<TH``!!
M54%455-(@>R(@0``2(D\)$B-;"0<3(GW2(GN9$B+!"4H````2(F$)'B!``!(
MC067*```2,=$)#``````2,>$)(@`````````2,=$)%``````2(E$)"A(C04`
M*0``2(E$)&A(C055*0``2(E$)'!(C04%*0``2(E$)'A(C05%*0``2(F$)(``
M``!(C04Z*0``2(E$)$@QP.B([O__2(7`=`R`.`!)B<0/A:<$``#HXNC__XG'
MZ(OH__](A<`/A.H#``!,BRA-A>T/A-X#``!,B>_HGNC__TB-?``!Z+3I__]%
M#[9%`$F)Q$6$P'0^38GG2(T=W"@```\?1```10^VP$R)_TB)V;X!````2,?"
M_____S'`28/%`4F#QP+HX^K__T4/MD4`183`==%(C5PD8$B-/2TH``#K%`\?
M`$B+>PA(@\,(2(7_#X0W`0``2(GN,<#HS>W__TF)Q4B%P'3=@#@`=-A(B<?H
M"/#__X7`=,Q,B>_H;.K__TF)P$B%P`^$``$``$R)QTR)1"0(Z./G__],B>=(
MB</HV.?__T2-O`,$!```36/_3(G_Z.7H__]!5$R-#2PG``!(C0T9*```28G%
M2(T%&"@``$C'PO____^^`0```%!,BT0D&$R)[S'`Z!_J__],B>^^P`$``.CR
MYO__7T%8@_C_=1+HM>;__T2+"$&#^1$/A10#``!(C90DD````$R)[K\!````
MZ(/I__^)PX7`#X2Y````2(L$)$V)Z+X!````13'D2(L]DX8``$B-%40H``!(
MBP@QP.B"Z?__2(N$)'B!``!D2"L$)2@````/A8(%``!(@<2(@0``3(G@6UU!
M7$%=05Y!7\-F#Q]$```QVTR-+2PG``#K&0\?1```2&/#3(MLQ"!-A>UT.T&`
M?0``=#1,B>^#PP'HP>[__X7`=-U,B>_H)>G__TF)P$B%P`^%N?[__TACPTR+
M;,0@387M=<D/'T``13'`Z:#^__^+A"2H````)0#P```]`$````^%,/___T2+
MI"2L````Z(SF__]!.<0/A1K___^+A"2H````)?\!```]P`$```^%`____TR)
M_^ADY___2(T]<28``$B)[DF)Q#'`Z.#K__](B<=(A<`/A$0"``#HC^C__TB)
MQDB+!"1(BSCH,//__TF)QTB%P`^$)`(``$R)_^C\Y?__2(G"@_@#?D1(F$B-
M-5TF``!(B50D"$F-?`?\Z*SF__^%P'4H2(M4)`B#^@0/A(X#``"-0OM(F$&`
M/`<O#X1^`P``9BX/'X0``````(L%NH0``(/X_P^$(0,``$B-/4DE``"%P`^$
MR`$``$B--;(E```QP$B-+2TF``#H[>[__TR-/0\F``#H`>7__U5(Q\+_____
M38GH4$R-#<XD``"^`0```$R)YTB-#=HE```QP.C8Y___6%KK1`\?0`#H>^3_
M_X,X$75(Z,'D__^#PP%(@^P(38GH54R-#8\D``!,B?F^`0```%-(Q\+_____
M3(GG4#'`Z)3G__](@\0@OL`!``!,B>?H8^3__X/X_W2N3(GOZ!;D__],B?=,
MB>8QP.A)[O__3(GGZ$'Z___IJOW__P\?0``QVTB-/?@D``#K$@\?1```2&/#
M2(M\Q$!(A?]T.$B)[C'`@\,!Z$[J__](A<!TX8`X`'3<2(G'Z/SF__])B<5(
MA<`/A=K[__](8\-(BWS$0$B%_W7(OPT```!,C2VE)```Z(+E__]!N%,```!)
MB<3IS?O__TB+!"1-B>B^`0```$4QY$B+/9Z#``!(C14/)0``2(L(,<#HC>;_
M_^D&_?__#Q^$``````!(B<?HB/G__TB+A"1X@0``9$@K!"4H````#X5X`@``
M2('$B($``$R)YUM=05Q!74%>05_I6.;__P\?A```````2(L$)$R+..G0_?__
MQP7:@@```````$R)_S'V,<#H?N7__TB-/68C``")Q87`#X0;_O__N@(```!(
MQ\;N____B<?HZN7__TB-G"1P`0``N@8```")[TB)WNA#Y/__@+PD<`$```!U
M#H"\)'$!``!##X1Z`0``,=(Q]HGOZ+#E__\QP.BY&P``28G'ZP\/'T``2(G>
M3(G_Z`4<``"Z`(```$B)WHGOZ/;C__^)PH7`?^")[TB-K"0@`0``2(T=?B,`
M`.B*X___3(G^2(GOZ&\=``!(C80D0`$``$B)1"0(28G'2(V$)&@!``!(B00D
M#Q\`1`^V10!,B?](B=F^`0```$C'PO____\QP$B#Q0%)@\<"Z%KE__],.3PD
M==1(C05H(P``QH0D:`$```!0_W0D$$B-#24C``!-B>A,B><QP+X!````3(T-
M!2(``$C'PO_____H&>7__UE>Z93]__]FD$B-/2@B```QP$B)[DB)/"3H&^C_
M_TB%P`^$CO[__P^V`(3`#X2#_O__/#`/A'O^___'!56!```!````2(L\).FJ
M_/__2(L$)$B+4`A(A=(/A'O\__](B==(B10DZ!_B__](@_@##X9E_/__2(L4
M)$B--8$B``!(C7P"_.C0XO__2(L4)(7`3`]$^NE!_/__@+PD<@$``$$/A7C^
M__^`O"1S`0``0P^%:O[__X"\)'0!``!(#X5<_O__@+PD=0$``$4/A4[^__^Z
M`@```$C'QL;___^)[^CVX___NBD```!(B=Z)[^A7XO__2(T%.R(``%!3Z=G^
M___HE.'__P\?0`!!54%454B#[!"+/9&```!D2(L$)2@```!(B40D"#'`Z&SB
M__^+/7:```!(B<7H7N+__P^VE;@```!(C6PD!$B-/<X@``!(B>Z(D+D````Q
MP.C;YO__2(7`=`F`.#$/A+4!```QP.A&\?__BSTP@```Z!OB__^Y`P```+H!
M````2(TUI"$``$B)Q^C2X?__28G$2(7`=#A(BT`0BST`@```3(LHZ.CA__](
MC15](0``2(G'3(GNZ!;A__])BT0D$$R+($'V1"0.0`^%D@$``(L]S'\``.BW
MX?__N0,```"Z`0```$B--4<A``!(B<?H;N'__TF)Q$B%P'0^2(T]X!\``$B)
M[C'`Z"7F__^+/8]_``!)B<5(A<`/A!,!``!)BT0D$$R+(.AFX?__3(GJ2(G'
M3(GFZ)C@__^+/6)_``#H3>'__[H!````2(TUY"```$B)Q^A9X?__BSU#?P``
M28G$Z"OA__],B>9(C179(```2(G'Z%G@__^+/2-_``#H#N'__TB)[DB-/4P?
M``#&@+D`````,<#HEN7__TB)!6>/``!)B<1(A<!T/[[``0``3(GGZ#K?__^-
M4`&#^@%V"8/X$0^%M````$B+1"0(9$@K!"4H````#X6]````2(/$$%U!7$%=
MPP\?`$B+/2&/``#H#/;__TB)!0V/``!)B<1(A<!UIDB-/>8@```QP.BOX/__
M#Q^``````(!X`0`/A$C^___I//[__V8/'X0``````$B+!=F.``!,BRA)BT0D
M$$R+(.A)X/__3(GN3(GGZ+[G___IX?[__V8/'X0``````(L].GX``.@EX/__
M3(GF2(G'Z'K@___I4_[__XG!2(L%C(X``$R)XDB-/8H@``!(BS`QP.@HX/__
MZ//>__\/'P!!5$F)_%532(/L$&1(BP0E*````$B)1"0(,<#H$.[__P^V$$B)
MQ832=!AF#Q]$``!(@\`!@/HO#[802`]$Z(32=>Z+!:A]``!-A>0/E<.#^/]T
M;87`#Y7`(<.$VW4B2(M$)`AD2"L$)2@````/A8\```!(@\006UU!7,,/'T0`
M`$&`/"0`=->Z!````$B--;H>``!(B>_HI=W__X7`=;](BT0D"&1(*P0E*```
M`'522(/$$$R)YUM=05SIH>3__Y`QP$B-="0$2(T]P1T``.B]X___2(7`=`L/
MM@"$P'0$/#!U#\<%`WT```````#I;/___\<%]'P```$```#I6?___^CJW?__
M9BX/'X0``````$%72(G^3(U/.$%6055!5%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>),C90D@````$F)T`\?@`````!!BP%)BSE)@\`028/!"`_(
MB<!(B?E)B4#P2(GX2,'I($C!Z"A(P>\X)0#_``!("?A(B<](P>$(2,'G&('A
M``#_`(G_2`GX2`G(28E`^$TYT'6N2(VZ``(```\?@`````!(BT)H2#-"0$B#
MP@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y^G753(L.3(M>$$B+?B!(
MBUX83(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY
M@EI,B=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!
MB=!,,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!
MX!Y/C903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,
MBVPD&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G!
M[1M(,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9
M>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'1
M3(G22<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!
M^$B)STC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]
M2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(
MP>(>18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%
M30GJ3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M
M&XG'3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*
MC8PIF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML
M)%`!P4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),
M,>)(`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)
MPDF)_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(
MP>`>2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB
M2<'B!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@Q
MT$G![1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>
M18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)
MZ4R+;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G2
M3"'`3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD
M+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(
MB<I(P>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,
M,<!,`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9
M>8):2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)
MZ$G![0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G!
M[1M(`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQ
MRD0QTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'7
M3(GB2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-
MC:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)
MZ$F)U8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GY
MB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP```
M`(G)23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9
M;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`
M2`.$)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,
MB<))P>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4
M).@```!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)
MP>H"2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H
M3HVL`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"
M2,'@'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC!
M[QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!)
M,<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B
M'D6)ZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#
MC"00`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$
M,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)
M[TP)T4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%
M3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,
MB=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)
M^$B)UXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG
M38G42<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-
ME!*AZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)
MY$DQT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY
M2,'O`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-
MB<1,`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G6
M08G222'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)
M]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!
M``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)
MXD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N
M&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)
M\DR+M"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"
M2,'B'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,
M`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.
M32'&3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!
MU4R)PDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)
M`<9,`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)
MX4&)S$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!
MX@5-"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+
MM"2(`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"
M2,'A'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-
MB<1)P>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^
M3"'!3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!
MS4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,
M`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)
MUD&)U$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-
M"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P
M`0``20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)
MP$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)
MP>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'2
M3`GR3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!
MZ`)(P>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-
MB>A(`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)
M^4PAZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;
M2,'A!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)
M"?U*C3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H
M`DC!X!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)
MP>P;2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0Q
MYTR+I"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F
M'D6)Y$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y
M3(N\)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G1
M2<'M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)
M`<9,`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR
M2<'L&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)
M`<5,`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI
M2<'J&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)
M`<1,`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M
M`DC!XAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),
M`=%-B>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G1
M2<'M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,
M`?)-B>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'4
M3(GR2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)
M`<5,`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ
M2<'L&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*
M20'$2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)
MXDV)[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!
MP$V)Z$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0Q
MQTF)R$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)
MT$C!Z@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$
MF`(``%M=05Q!74%>05_#Z+#'__](@^P(OX````#HLLC__[J)J\WON?[<NIB^
M\.'2PTC'``$C16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,```
M``#'0'@`````2(/$",-F9BX/'X0``````)!!5TACPD%628G&055!5$F)_%5(
MC6\X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(
M8T=XA<`/A>T```!!@_X_#XXK`0``08/N0$6)]T'![P9%C6\!2<'E!DD!W0\?
M1```\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0\P]O4^`/$54@\P]O6_`/$5TP
MZ-'H__],.>MUS$'!YP9%*?Y)8\9(@_@(<EQ)BU4`2(U-"$B#X?A)B50D.$F+
M5`7X2(E4!?A(*<U(`>A)*>U(@^#X2(/X"'(82(/@^#'228MT%0!(B3012(/"
M"$@YPG+N18ET)'A(@\0(6UU!7$%=05Y!7\-FD*@$=71(A<!TX4$/ME4`08A4
M)#BH`G3300^W5`7^9HE4!?[KQ@\?0`!!O4````!(C7P%`$B)WD$IQ44Y]44/
M3^Y-8_U,B?KHU<;__T&+1"1X1`'H08E$)'B#^$!UDDR)YT4I[DP!^^CUY___
MZ<O^__])B=WI(____T&+50!!B50D.$&+5`7\B50%_.E;____D$%63(UV.$%5
M05152(GU4TB+1BA(B?M$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$!CB`
M2&/!3`'P@_DX#XX4`0``OD`````ISG0/,=*)T8/"`<8$"``Y\G+S2(GOZ&SG
M__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&($2);7!(B>]$B65TZ$+G__](
MBT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`B&,"2(M%`(A#`TB+10A(P>@8
MB$,$2(M%"$C!Z!"(0P5(BT4(B&,&2(M%"(A#!TB+11!(P>@8B$,(2(M%$$C!
MZ!"(0PE(BT40B&,*2(M%$(A#"TB+11A(P>@8B$,,2(M%&$C!Z!"(0PU(BT48
MB&,.2(M%&(A##TB+12!(P>@8B$,02(M%($C!Z!"(0Q%(BT4@B&,22(M%((A#
M$UM=05Q!74%>Z7_#__\/'X``````NC@````Q_RG*@_H(<DJ)T4C'``````!(
MQT0(^`````!(C4@(2(/A^$@IR`'"@^+X@_H(#X+M_O__@^+X,<")QH/`"$B)
M/#$YT'+SZ=;^__\/'X0``````/;"!'4CA=(/A,'^___&``#VP@(/A+7^__\Q
MR6:)3!#^Z:G^__\/'P#'``````#'1!#\`````.F3_O__#Q]$``!!5TR-/7=>
M``!!5DF)UD%528GU051!B?Q52(TM:%X``%-,*?U(@^P(Z(/"__](P?T#=!LQ
MVP\?`$R)\DR)[D2)YT'_%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\,/'P##
M9BX/'X0```````\?1```2(L-06(``.G$P___2(/L"$B#Q`C#````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R
M>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3(`+64`+2T``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(
M+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@
M,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F
M*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0[
M"G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%
M(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N
M<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N
M*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E
M>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I
M9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.
M5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U
M9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L
M92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM
M>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E
M='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B
M.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ
M;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE
M(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I
M.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H
M+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)
M3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I
M;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE
M;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D
M+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M
M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]
M"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N
M;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R
M96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@
M)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL
M97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R
M96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?
M1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O
M<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*
M;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R
M(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE
M;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E
M("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC
M;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!
M4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@
M/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.
M5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO
M=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q
M6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D[
M"B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM
M>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^
M:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I
M92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!P
M97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`!&P,[_````!X```"0@?__2`$``!"%__]P`0``((7__P@&```PA___&`$`
M`""(__^(`0``\(C__]0!``!PBO__&`(```"+__\\`@``X(O__W@"```@CO__
MQ`(``)".___<`@``P([___0"``"`C___*`,``)"/__\\`P``D)'__YP#``#`
MD?__L`,``*"2___@`P``0)?__S`$``#`E___3`0``."7__]D!```\)C__\`$
M``#PH/__D`4``)"C___$!0``H*3__S@&``#0NO__B`8``#"[__^@!@``T+S_
M_^P&``#`OO__,`<``""___]X!P``,+___Y`'````````%``````````!>E(`
M`7@0`1L,!PB0`0<0%````!P````0AO__*P``````````````%``````````!
M>E(``7@0`1L,!PB0`0``)````!P```!`@/__@`,````.$$8.&$H/"W<(@``_
M&CLJ,R0B`````!0```!$````F(/__P@``````````````$@```!<````D(;_
M_\T`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$
M#C!!#BA"#B!"#AA"#A!"#@A)"P!`````J````!2'__]T`0```$(.$(X"0@X8
MC0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"``
M``#L````4(C__XL`````00X0A@)2#K`!`G$*#A!!#@A!"S@````0`0``O(C_
M_]T`````0@X0C@)'#AB-`T(.((P$1`XHA@51#L`@`J,*#BA!#B!"#AA"#A!"
M#@A&"T@```!,`0``8(G__S$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D0..(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L4````F`$``%2+
M__]I`````$0.$`)@#@@4````L`$``*R+__\P`````$0.$%8."``P````R`$`
M`,2+__^_`````$(.$(P"00X8A@-!#B"#!$<.P$`"IPH.($0.&$$.$$(."$$+
M$````/P!``!0C/__!0````````!<````$`(``$R,___R`0```$(.$(\"0@X8
MC@-%#B"-!$(.*(P%00XPA@9+#CB#!T<.@"("9`H..$$.,$$.*$(.($(.&$(.
M$$(."$0+`I\.B")0#I`B70Z((D$.@"(````0````<`(``.R-__\E````````
M`"P```"$`@``"([__]P`````2@X0A@("8@K&#@A,"WD*#@A'"T@*Q@X(10M+
M#@C&`$P```"T`@``N([__YX$````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D$..(,'2PZ``0,S!`H..$$.,$$.*$(.($(.&$(.$$(."$$+````&`````0#
M```(D___=`````!$#B!M"@X(1PL``!0````@`P``;)/__QT`````1`X06`X(
M`%@````X`P``=)/__PL!````0@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.
M*$8.($$.&$(.$$(."$P+9`H.*$$.($$.&$(.$$(."$8+80Y(20Y08PY(00Y`
M````S````)0#```HE/___`<```!"#A"/`D(.&(X#20X@C01"#BB,!4$.,(8&
M00XX@P='#L"#`@.E`0[(@P)E#M"#`ET.R(,"0@[`@P(">PH..$0.,$$.*$(.
M($(.&$(.$$(."$<+`X`!#LB#`DL.T(,"7@[(@P)!#L"#`EP.R(,"1`[0@P)0
M#MB#`DL.X(,"2P[`@P(#!@$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P,L`0[(
M@P)$#M"#`F@.R(,"00[`@P("^`H.R(,"00[0@P)%"S````!D!```6)O__YT"
M````0@X0C0)"#AB,`T$.((8$1`XP`]8!"@X@00X80@X00@X(1`M`````F`0`
M`,2=__\&`0```$(.$(P"1`X8A@-!#B"#!$0.,`)K"@X@00X800X00@X(1@MS
M"@X@1`X800X00@X(1@L``"P```#<!```$'___P<"````0@X0C`)!#AB&`T0.
M4`.<`0H.&$0.$$(."$$+`````$P````,!0``8)[__S`6````0@X0CP))#AB.
M`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0,(%@H..$$.,$$.*$(.($(.&$(.
M$$(."$$+````%````%P%``!`M/__5`````!$#A`"3PX(2````'0%``"(M/__
MGP$```!"#A"/`D4.&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"Y0H..$$.
M,$$.*$(.($(.&$(.$$(."$,+`$````#`!0``W+7__^L!````0@X0C@)&#AB-
M`T(.((P$00XHA@5$#C"#!@,V`0H.*$$.($(.&$(.$$(."$P+````````1```
M``0&``"(M___70````!"#A"/`DD.&(X#10X@C01%#BB,!40.,(8&2`XX@P='
M#D!J#CA!#C!!#BA"#B!"#AA"#A!"#@@`%````$P&``"@M___`0``````````
M````$````&0&``"8M___#```````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````*`F````````8"8````````!`````````/("
M`````````0`````````"`P````````$`````````$@,````````,````````
M```@````````#0````````#,70```````!D`````````T+L````````;````
M``````@`````````&@````````#8NP```````!P`````````"`````````#U
M_O]O``````@#````````!0`````````@#0````````8`````````"`0`````
M```*`````````)T$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````H!0```````!0`````````
M!P`````````7`````````(`4````````!P``````````$P````````@`````
M````@`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`2````````____;P`````"````````
M`/#__V\`````OA$```````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#@NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,```````"6(P``````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$1E8FEA;B`Q,2XR+C`M,3`I(#$Q+C(N,```+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN
M:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y
M`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@````````"H`@```````*@"
M````````'`````````````````````$````````````````````3````!P``
M``(`````````Q`(```````#$`@```````"0````````````````````$````
M````````````````)@````<````"`````````.@"````````Z`(````````@
M````````````````````!````````````````````#0```#V__]O`@``````
M```(`P````````@#````````_``````````%``````````@`````````````
M```````^````"P````(`````````"`0````````(!````````!@)````````
M!@````$````(`````````!@`````````1@````,````"`````````"`-````
M````(`T```````"=!````````````````````0```````````````````$X`
M``#___]O`@````````"^$0```````+X1````````P@`````````%````````
M``(``````````@````````!;````_O__;P(`````````@!(```````"`$@``
M`````(``````````!@````(````(````````````````````:@````0````"
M```````````3`````````!,```````"``0````````4`````````"```````
M```8`````````'0````$````0@````````"`%````````(`4````````*`4`
M```````%````%@````@`````````&`````````!^`````0````8`````````
M`"``````````(````````!<````````````````````$````````````````
M````>0````$````&`````````"`@````````("````````"``P``````````
M````````$``````````0`````````(0````!````!@````````"@(P``````
M`*`C````````"`````````````````````@`````````"`````````"-````
M`0````8`````````L",```````"P(P```````!PZ```````````````````0
M````````````````````DP````$````&`````````,Q=````````S%T`````
M```)````````````````````!````````````````````)D````!`````@``
M````````8`````````!@````````D#X``````````````````!``````````
M``````````"A`````0````(`````````D)X```````"0G@```````/P`````
M```````````````$````````````````````KP````$````"`````````)"?
M````````D)\```````"H!@``````````````````"```````````````````
M`+D````.`````P````````#0NP```````-"K````````"```````````````
M``````@`````````"`````````#%````#P````,`````````V+L```````#8
MJP````````@````````````````````(``````````@`````````T0````8`
M```#`````````."[````````X*L````````0`@````````8`````````"```
M```````0`````````(@````!`````P````````#PO0```````/"M````````
M$`(```````````````````@`````````"`````````#:`````0````,`````
M`````,``````````L````````"`````````````````````(````````````
M````````X`````@````#`````````"#`````````(+````````"`$```````
M````````````(````````````````````.4````!````,```````````````
M`````""P````````'P````````````````````$``````````0`````````!
M`````P`````````````````````````_L````````.X`````````````````
2```!````````````````````
